<?php
/*
Plugin Name: Fedya's Smart Content Protection
Description: Интелигентна защита на съдържанието с лимит за копиране
Version: 1.2
Author: Fedya Serafiev
website: https://urocibg.eu/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

// Предотвратява директния достъп до файла
if (!defined('ABSPATH')) {
    exit;
}

class SmartContentProtection {
    private $replacement_text = '🤡 Имало едно време, един дядо на име Бай Хуй. Той все обичал да повтаря "Не-пип, че пляс".👋';
    private $word_limit = 70;

    public function __construct() {
        // Добавяме необходимите действия
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_filter('the_content', array($this, 'protect_images'));
        add_action('wp_head', array($this, 'add_protection_css'));
        add_action('wp_footer', array($this, 'add_copy_protection_script'));
    }

    // Зареждане на JavaScript
    public function enqueue_scripts() {
        wp_enqueue_script(
            'content-protection',
            plugins_url('js/protection.js', __FILE__),
            array('jquery'),
            '1.2',
            true
        );

        // Подаване на настройките към JavaScript
        wp_localize_script(
            'content-protection',
            'contentProtectionVars',
            array(
                'replacementText' => $this->replacement_text,
                'wordLimit' => $this->word_limit
            )
        );
    }

    // Добавяне на CSS защита за изображения
    public function add_protection_css() {
        ?>
        <style>
            img {
                -webkit-user-select: none;
                -khtml-user-select: none;
                -moz-user-select: none;
                -o-user-select: none;
                user-select: none;
                -webkit-user-drag: none;
                -khtml-user-drag: none;
                -moz-user-drag: none;
                -o-user-drag: none;
                user-drag: none;
                pointer-events: none;
            }
        </style>
        <?php
    }

    // Защита на изображенията в съдържанието
    public function protect_images($content) {
        if (!is_feed()) {
            $content = preg_replace(
                '/<img(.*?)src=[\'"](.*?)[\'"](.*?)>/i',
                '<img$1src="$2"$3 oncontextmenu="return false;">',
                $content
            );
        }
        return $content;
    }

    // Добавяне на скрипт за интелигентна защита на копирането
    public function add_copy_protection_script() {
        ?>
        <script>
            document.addEventListener('copy', function(e) {
                var selectedText = window.getSelection().toString();
                var wordCount = selectedText.trim().split(/\s+/).length;
                
                if (wordCount > <?php echo $this->word_limit; ?>) {
                    e.preventDefault();
                    var clipboardData = e.clipboardData || window.clipboardData;
                    clipboardData.setData('text/plain', '<?php echo addslashes($this->replacement_text); ?>');
                }
            });
        </script>
        <?php
    }
}

// Инициализация на плъгина
function init_smart_content_protection() {
    new SmartContentProtection();
}

add_action('plugins_loaded', 'init_smart_content_protection');
